@@ -1,7 +1,6 @@
 import datetime as dt
 import os
 from dataclasses import asdict
-from shutil import rmtree
 from subprocess import check_call
 
 import typer
@@ -18,12 +17,13 @@ from .naming import (
     CRON_ENV_VAR,
     MAIN_MODULE_NAME,
     SANDBOX_DIR,
-    SANDBOX_NAME,
     TEMPLATE_REPO,
 )
 from .pipeline_registry import get_global_pipereg
 from .registry import Registry
-from .utils import get_git_diffs, git_run
+from .sql.draw import dump_graph
+from .sql.loader import tmp_constr
+from .utils import gen_rmtree, get_git_diffs, git_run
 from .validation_functions import validate, validate_importable
 
 logger = get_logger(ctx="CLI command")
@@ -56,13 +56,27 @@ def init(name: str):
     check_call(["git", "remote", "rename", "origin", "template"], cwd=name)
 
 
+@app.command()
+def update():
+    update_registry()
+    git_run(pull=True)
+    Repo().pull()
+
+
+@app.command()
+def draw(v: bool = False):
+    with tmp_constr(v) as constr:
+        dump_graph(constr)
+
+
 @app.command()
 def publish_data(validate: bool = False):
-    # TODO: current meta should be built and published
+    build_meta()
     _validate_empty_vc("publishing data")
     runtime = get_runtime(True)
     dvc_repo = Repo()
     data_version = runtime.metadata.next_data_v
+    vtags = []
     for env in runtime.config.sorted_envs:
         targets = runtime.pipereg.step_names_of_env(env.name)
         logger.info("pushing targets", targets=targets, env=env.name)
@@ -70,8 +84,10 @@ def publish_data(validate: bool = False):
         vtag = get_tag(runtime.config.version, data_version, env.name)
         _commit_dvc_default(env.remote)
         check_call(["git", "tag", vtag])
-        check_call(["git", "push", "origin", vtag])
+        vtags.append(vtag)
     git_run(push=True)
+    for tag_to_push in vtags:
+        check_call(["git", "push", "origin", tag_to_push])
     runtime.registry.publish()
     if validate:
         validate_importable(runtime)
@@ -107,13 +123,8 @@ def load_external_data(git_commit: bool = False):
 @app.command()
 def cleanup():
     conf = Config.load()
-    aname = conf.name
-    reg = Registry(conf, True)
-    check_call(["pip", "uninstall", aname, "-y"])
-    reg.purge()
-    if SANDBOX_DIR.exists():
-        check_call(["pip", "uninstall", SANDBOX_NAME, "-y"])
-        rmtree(SANDBOX_DIR.as_posix())
+    Registry(conf).purge()
+    gen_rmtree(SANDBOX_DIR)
 
 
 @app.command()
@@ -127,10 +138,10 @@ def run_cronjobs(cronexpr: str = None, commit: bool = True):
 
 @app.command()
 def run(
-    stage: bool = True, profile: bool = False, env: bool = None, commit: bool = False
+    stage: bool = True, profile: bool = False, env: str = None, commit: bool = False
 ):
     dvc_repo = Repo(config={"core": {"autostage": stage}})
-    runtime = get_runtime()
+    runtime = get_runtime(True)
     stage_names = []
     for step in runtime.pipereg.steps:
         logger.info("adding step", step=step)
@@ -145,7 +156,7 @@ def run(
         dvc_repo.lock.lock()
         stage.remove_outs(force=True)
         dvc_repo.lock.unlock()
-    targets = runtime.pipereg.step_names_of_env(env.name) if env else None
+    targets = runtime.pipereg.step_names_of_env(env) if env else None
     rconf = RunConfig(profile=profile)
     with rconf:
         logger.info("running repro", targets=targets, **asdict(rconf))
