@@ -1,4 +1,4 @@
-import metazimmer.dogshowbase.core as dogcore
+# import metazimmer.dogshowbase.core as dogcore
 
 # import metazimmer.dogsuccess.success as dogsucc
 import pandas as pd
@@ -9,18 +9,18 @@ import datazimmer as dz
 # based on DotM and race
 
 
-class DogSuccessFeatures(dz.TableFeaturesBase):
+class DogSuccess(dz.AbstractEntity):
 
     thing = int
     # success = dogsucc.StatusIndex TODO import data for validation
     # based on dotm  and competitions in ds2
 
 
-ds_table = dz.ScruTable(DogSuccessFeatures, subject_of_records=dogcore.Dog)
+ds_table = dz.ScruTable(DogSuccess)
 
 
 @dz.register(outputs=[ds_table])  # dependencies=[dogsucc.status_table]
 def proc():
     # TODO - give this some logic
     # dogsucc.status_table.get_full_df().index[:3]
-    pd.DataFrame({DogSuccessFeatures.thing: [1, 2, 3]}).pipe(ds_table.replace_all)
+    pd.DataFrame({DogSuccess.thing: [1, 2, 3]}).pipe(ds_table.replace_all)
